@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::IDOPEREL;
 BEGIN {
-  $Dist::Zilla::PluginBundle::IDOPEREL::VERSION = '0.1';
+  $Dist::Zilla::PluginBundle::IDOPEREL::VERSION = '0.2';
 }
 
 use Moose;
@@ -15,11 +15,14 @@ use Dist::Zilla::PluginBundle::Classic;
 use Dist::Zilla::PluginBundle::Git;
 use Dist::Zilla::Plugin::MetaJSON;
 use Dist::Zilla::Plugin::MinimumPerl;
-use Dist::Zilla::Plugin::AutoPrereq;
+use Dist::Zilla::Plugin::AutoPrereqs;
 use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::GithubMeta;
 use Dist::Zilla::Plugin::TestRelease;
 use Dist::Zilla::Plugin::ReadmeFromPod;
+use Dist::Zilla::Plugin::LoadTests;
+use Dist::Zilla::Plugin::CheckChangesHasContent;
+use Dist::Zilla::Plugin::DistManifestTests;
 
 =head1 NAME
 
@@ -27,7 +30,7 @@ Dist::Zilla::PluginBundle::IDOPEREL - IDOPEREL's plugin bundle for Dist::Zilla.
 
 =head1 VERSION
 
-version 0.1
+version 0.2
 
 =head1 SYNOPSIS
 
@@ -65,12 +68,15 @@ This bundle provides the following plugins and bundles:
 	[Manifest]
 	[ConfirmRelease]
 	[UploadToCPAN]
-	[AutoPrereq]
+	[AutoPrereqs]
 	[@Git]
 	[NextRelease]
 	[GithubMeta]
 	[ReadmeFromPod]
 	[TestRelease]
+	[LoadTests]
+	[CheckChangesHasContent]
+	[DistManifestTests]
 
 =head1 INTERNAL METHODS
 
@@ -98,12 +104,15 @@ sub bundle_config {
 
 	my $prefix = 'Dist::Zilla::Plugin::';
 	my @extra = map { [ "$class/$prefix$_->[0]" => "$prefix$_->[0]" => $_->[1] ] } (
-		[ AutoPrereq          => { skip  => $arg->{auto_prereq_skip} } ],
-		[ MetaJSON            => {} ],
-		[ MinimumPerl         => {} ],
-		[ NextRelease         => {} ],
-		[ ReadmeFromPod       => {} ],
-		[ TestRelease         => {} ],
+		[ AutoPrereqs			=> { skip  => $arg->{auto_prereqs_skip} } ],
+		[ MetaJSON			=> {} ],
+		[ MinimumPerl			=> {} ],
+		[ NextRelease			=> {} ],
+		[ ReadmeFromPod			=> {} ],
+		[ LoadTests			=> {} ],
+		[ CheckChangesHasContent	=> {} ],
+		[ DistManifestTests		=> {} ],
+		[ TestRelease			=> {} ],
 	);
 
 	push (@plugins, @extra);
